@@ -42,6 +42,7 @@
 #include "log.h"
 #include "connection_list.h"
 #include "event.h"
+#include "libc_compat.h"
 
 #include "input_layer.h"
 
@@ -112,8 +113,11 @@ static struct evtab_entry evtab[] = {
  		"button/volumeup VOLUP 00000080 00000000"},
 	{{{0,0}, EV_KEY, KEY_MUTE, 1},
  		"button/mute MUTE 00000080 00000000"},
+/* Kernel 3.1 or later required for KEY_MICMUTE */
+#ifdef KEY_MICMUTE
 	{{{0,0}, EV_KEY, KEY_MICMUTE, 1},
 		"button/micmute MICMUTE 00000080 00000000"},
+#endif
  	/* cd play/pause buttons */
  	{{{0,0}, EV_KEY, KEY_NEXTSONG, 1},
  		"cd/next CDNEXT 00000080 00000000"},
@@ -144,10 +148,12 @@ static struct evtab_entry evtab[] = {
 		"jack/lineout LINEOUT unplug"},
 	{{{0,0}, EV_SW, SW_LINEOUT_INSERT, 1},
 		"jack/lineout LINEOUT plug"},
+#ifdef SW_VIDEOOUT_INSERT
 	{{{0,0}, EV_SW, SW_VIDEOOUT_INSERT, 0},
 		"jack/videoout VIDEOOUT unplug"},
 	{{{0,0}, EV_SW, SW_VIDEOOUT_INSERT, 1},
 		"jack/videoout VIDEOOUT plug"},
+#endif
 	{{{0,0}, EV_SW, SW_LINEIN_INSERT, 0},
 		"jack/linein LINEIN unplug"},
 	{{{0,0}, EV_SW, SW_LINEIN_INSERT, 1},
@@ -181,6 +187,8 @@ static struct evtab_entry evtab[] = {
 	{{{0,0}, EV_KEY, KEY_F24, 1}, "button/f24 F24 00000080 00000000"},
 	{{{0,0}, EV_KEY, KEY_KBDILLUMTOGGLE, 1},
  		"button/kbdillumtoggle KBILLUM 00000080 00000000"},
+	{{{0,0}, EV_KEY, KEY_COPY, 1}, "button/copy COPY 00000080 00000000"},
+	{{{0,0}, EV_KEY, KEY_RESTART, 1}, "button/restart RSTR 00000080 00000000"},
 
 #if 0
 	/* These "EV_MSC, 4, x" events cause trouble.  They are triggered */
