@@ -50,6 +50,17 @@ int clientmax = ACPID_CLIENTMAX;
 /* the number of non-root clients that are connected */
 int non_root_clients;
 
+#ifndef HAVE_ISFDTYPE
+static int
+isfdtype(int fd, int fdtype)
+{
+	struct stat64 st;
+	if (fstat64(fd, &st) != 0)
+		return -1;
+	return ((st.st_mode & S_IFMT) == (mode_t)fdtype);
+}
+#endif
+
 /* determine if a file descriptor is in fact a socket */
 int
 is_socket(int fd)
